@@ -1,4 +1,5 @@
 import os
+import sys
 import warnings
 
 try:
@@ -14,6 +15,9 @@ from pyfits.card import Card, CardList, RecordValuedKeywordCard, \
 from pyfits.util import BLOCK_SIZE, deprecated
 
 
+PY3K = sys.version_info[:2] >= (3, 0)
+
+
 class Header(__HEADERBASE):
     """
     FITS header class.
@@ -198,6 +202,14 @@ class Header(__HEADERBASE):
     def keys(self):
         """
         Return a list of keys with duplicates removed.
+
+        .. warning::
+            There is a surprising incogruity in Header objecets between
+            :meth:`Header.keys` and :meth:`Header.iterkeys`.  The latter does
+            *not* remove duplicates.  This incongruity exists for historical
+            reasons, but is not be design.  In PyFITS 3.1 it is done away with,
+            and :meth:Header.keys returns the exact keywords appearin the
+            header, including duplicates.
         """
 
         retval = []
@@ -208,6 +220,61 @@ class Header(__HEADERBASE):
 
         return retval
 
+    def itervalues(self):
+        """
+        Override itervalues since the default implementation does not
+        properly handle duplicate keywords.
+        """
+
+        for card in self.ascard:
+            yield card.value
+
+    def iteritems(self):
+        """
+        Override iteritems since the default implementation does not properly
+        handle duplicate keywords.
+        """
+
+        for card in self.ascard:
+            yield (card.key, card.value)
+
+    def values(self):
+        """
+        Override values since the default implementation does not properly
+        handle duplicate keywords.
+        """
+
+        return list(self.itervalues())
+
+    def items(self):
+        """
+        Override items since the default implementation does not propertly
+        handle duplicate keywords.
+        """
+
+        return list(self.iteritems())
+
+    # Some fixes for compatibility with the Python 3 dict interface, where
+    # iteritems -> items, etc.
+    if PY3K:  # pragma: py3
+        values = itervalues
+        items = iteritems
+        del itervalues
+        del iteritems
+
+    def setdefault(self, keyword, default=''):
+        """
+        PyFITS < 3.1 won't allow item assignment to keywords that don't already
+        exist, but for the setdefault dict method to work at all, it needs to
+        be able to add nonexistent keywords with the default value.
+        """
+
+        try:
+            return self[keyword]
+        except KeyError:
+            self.update(keyword, default)
+            return default
+
     def update(self, key, value, comment=None, before=None, after=None,
                savecomment=False):
         """
